#!/usr/bin/env python
# -*- coding: utf-8 -*-

from flask import Flask, request, session, g, redirect, url_for, abort, \
    render_template, flash
import sqlite3
from datetime import date, timedelta
import locale
locale.setlocale(locale.LC_ALL, '')

DATABASE = '/tmp/cavote.db'
SECRET_KEY = '{J@uRKO,xO-PK7B,jF?>iHbxLasF9s#zjOoy=+:'
DEBUG = True
USERNAME = 'admin'
PASSWORD = 'admin'

app = Flask(__name__)
app.config.from_object(__name__)

def connect_db():
    return sqlite3.connect(app.config['DATABASE'])

@app.before_request
def before_request():
    g.db = connect_db()

@app.teardown_request
def teardown_request(exception):
    g.db.close()

@app.route('/')
def home():
    return render_template('index.html')

@app.route('/admin/votes')
def show_votes():
    cur = g.db.execute('select title, description, date_begin, date_end from votes order by id desc')
    votes = [dict(title=row[0], description=row[1], date_begin=row[2], date_end=row[3], 
        pourcent=60) for row in cur.fetchall()]
    return render_template('show_votes.html', votes=votes)

@app.route('/admin/votes/new')
def new_vote():
    if not session.get('logged_in'):
        abort(401)
    return render_template('new_vote.html')

@app.route('/admin/vote/add', methods=['POST'])
def add_vote():
    if not session.get('logged_in'):
        abort(401)
    daten = date.today() + timedelta(days=int(request.form['days']))
    ndate = daten.strftime('%d %B %Y')
    transparent = 0
    public = 0
    multiplechoice = 0
    if 'transparent' in request.form.keys():
        transparent = 1
    if 'public' in request.form.keys():
        public = 1
    if 'multiplechoice' in request.form.keys():
        multiplechoice = 1
    g.db.execute('insert into votes (title, description, date_end, is_transparent, is_public, is_multiplechoice) values (?, ?, ?, ?, ?, ?)',
            [request.form['title'], request.form['description'], ndate, transparent, public, multiplechoice])
    g.db.commit()
    flash('New entry was successfully posted')
    return redirect(url_for('home'))

@app.route('/login', methods=['GET', 'POST'])
def login():
    error = None
    if request.method == 'POST':
        if request.form['username'] != app.config['USERNAME']:
            error = 'Invalid username'
        elif request.form['password'] != app.config['PASSWORD']:
            error = 'Invalid password'
        else:
            session['logged_in'] = True
            session['nickname'] = request.form['username']
            if session['nickname'] == 'admin':
                session['is_admin'] = True
            flash('You were logged in')
            return redirect(url_for('home'))
    return render_template('login.html', error=error)

@app.route('/logout')
def logout():
    session.pop('logged_in', None)
    flash('You were logged out')
    return redirect(url_for('home'))



if __name__ == '__main__':
    app.run()


